@@ -1,5 +1,5 @@
 use cfg_rs::*;
-use std::collections::HashMap;
+use std::{collections::HashMap, env::set_var};
 
 type R<V> = Result<V, ConfigError>;
 
@@ -33,8 +33,12 @@ struct IntSuit {
 }
 
 fn main() -> Result<(), ConfigError> {
+    set_var("RUST_LOG", "trace");
+    env_logger::init();
     // This example need feature full to enable toml/yaml/json source, and load them from app.toml/yaml/json.
-    let config = Configuration::with_predefined()?;
+    let config = Configuration::with_predefined_builder()
+        .set_profile("dev")
+        .init()?;
     let mut i = 0;
     for name in config.source_names() {
         i += 1;
