@@ -42,7 +42,7 @@ pub type ConfigKey<'a> = CacheKey<'a>;
 #[derive(Debug)]
 pub(crate) struct CacheString {
     current: String,
-    mark: Vec<(usize, usize)>,
+    mark: usize,
 }
 thread_local! {
     static BUG: RefCell<CacheString> = RefCell::new(CacheString::new());
@@ -51,35 +51,31 @@ impl CacheString {
     pub(crate) fn new() -> CacheString {
         Self {
             current: String::with_capacity(10),
-            mark: Vec::with_capacity(3),
+            mark: 0,
         }
     }
 
     #[inline]
     #[allow(single_use_lifetimes)]
-    fn push<'a, I: IntoIterator<Item = PartialKey<'a>>>(&mut self, iter: I) {
-        let mut step = 0;
-        let len = self.current.len();
+    fn push<'a, I: IntoIterator<Item = PartialKey<'a>>>(&mut self, iter: I) -> usize {
+        let mark = self.mark;
+        self.mark = self.current.len();
         for i in iter {
-            step += 1;
             i.update_string(&mut self.current);
         }
-        self.mark.push((step, len));
+        mark
     }
 
     #[inline]
-    fn pop(&mut self) {
-        if let Some((s, l)) = self.mark.pop() {
-            if s > 0 {
-                self.current.truncate(l);
-            }
-        }
+    fn pop(&mut self, mark: usize) {
+        self.current.truncate(self.mark);
+        self.mark = mark;
     }
 
     #[inline]
     fn clear(&mut self) {
         self.current.clear();
-        self.mark.clear();
+        self.mark = 0;
     }
 
     #[inline]
@@ -110,24 +106,23 @@ impl Drop for CacheKey<'_> {
 }
 
 impl<'a> CacheKey<'a> {
-    pub(crate) fn push<I: Into<PartialKeyIter<'a>>>(&mut self, iter: I) {
-        self.cache.push(iter.into());
+    pub(crate) fn push<I: Into<PartialKeyIter<'a>>>(&mut self, iter: I) -> usize {
+        self.cache.push(iter.into())
     }
-    pub(crate) fn pop(&mut self) {
-        self.cache.pop();
+    pub(crate) fn pop(&mut self, mark: usize) {
+        self.cache.pop(mark);
     }
 
     /// As string
     pub(crate) fn as_str(&self) -> &str {
         &self.cache.current
     }
-
-    /// To String.
-    pub(crate) fn to_string(&self) -> String {
-        self.as_str().to_string()
+}
+impl std::fmt::Display for CacheKey<'_> {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        write!(f, "{}", self.as_str())
     }
 }
-
 /// Partial key, plese refer to [`ConfigKey`].
 #[allow(single_use_lifetimes)]
 #[derive(Debug, PartialEq, Eq)]
@@ -169,7 +164,7 @@ impl<'a> Iterator for PartialKeyIter<'a> {
     fn next(&mut self) -> Option<Self::Item> {
         match self {
             PartialKeyIter::Str(s) => {
-                while let Some(v) = s.next() {
+                for v in s {
                     if v.is_empty() {
                         continue;
                     }
@@ -202,16 +197,6 @@ impl<'a> PartialKeyCollector<'a> {
         }
     }
 
-    // #[allow(dead_code)]
-    // /// Add string key.
-    // pub(crate) fn insert_str(&mut self, key: &'a str) {
-    //     if let Ok(i) = key.parse() {
-    //         self.insert_int(i);
-    //     } else {
-    //         self.str_key.insert(key);
-    //     }
-    // }
-
     /// Add index of array.
     pub(crate) fn insert_int(&mut self, key: usize) {
         if let Some(u) = self.int_key {
@@ -223,33 +208,27 @@ impl<'a> PartialKeyCollector<'a> {
     }
 }
 
-// impl<'a> Into<PartialKey<'a>> for &'a str {
-//     fn into(self) -> PartialKey<'a> {
-//         PartialKey::Str(self)
-//     }
-// }
-
-impl<'a> Into<PartialKeyIter<'a>> for &'a str {
-    fn into(self) -> PartialKeyIter<'a> {
-        PartialKeyIter::Str(self.split(&['.', '[', ']'][..]))
+impl<'a> From<&'a str> for PartialKeyIter<'a> {
+    fn from(s: &'a str) -> Self {
+        PartialKeyIter::Str(s.split(&['.', '[', ']'][..]))
     }
 }
 
-impl<'a> Into<PartialKey<'a>> for usize {
-    fn into(self) -> PartialKey<'a> {
-        PartialKey::Int(self)
+impl From<usize> for PartialKey<'_> {
+    fn from(s: usize) -> Self {
+        PartialKey::Int(s)
     }
 }
 
-impl<'a> Into<PartialKeyIter<'a>> for usize {
-    fn into(self) -> PartialKeyIter<'a> {
-        PartialKeyIter::Int(Some(self))
+impl From<usize> for PartialKeyIter<'_> {
+    fn from(s: usize) -> Self {
+        PartialKeyIter::Int(Some(s))
     }
 }
 
-impl<'a> Into<PartialKeyIter<'a>> for &'a String {
-    fn into(self) -> PartialKeyIter<'a> {
-        self.as_str().into()
+impl<'a> From<&'a String> for PartialKeyIter<'a> {
+    fn from(s: &'a String) -> Self {
+        s.as_str().into()
     }
 }
 
@@ -293,14 +272,15 @@ mod test {
             let mut che = CacheString::new();
             let mut key = che.new_key();
             let mut vec = vec![];
+            let mut xxx = vec![];
             $(
-                key.push($origin);
+                xxx.push(key.push($origin));
                 assert_eq!($norm, key.as_str());
                 vec.push(key.to_string());
             )+
             while let Some(v) = vec.pop() {
                 assert_eq!(&v, key.as_str());
-                key.pop();
+                key.pop(xxx.pop().unwrap());
             }
         };
     }
