@@ -99,6 +99,38 @@ pub use value::FromStringValue;
 
 use std::sync::*;
 
+pub(crate) mod macros {
+    macro_rules! cfg_log {
+    ($b:expr => $lvl:expr,$($arg:tt)+) => {
+        #[cfg(feature = "log")]
+        {
+            if  $b {
+                log::log!($lvl, $($arg)+);
+            }
+        }
+    };
+    ($lvl:expr,$($arg:tt)+) => {
+        #[cfg(feature = "log")]
+        {
+            log::log!($lvl, $($arg)+);
+        }
+    };
+    }
+
+    macro_rules! impl_default {
+        ($x:ident) => {
+            impl Default for $x {
+                fn default() -> Self {
+                    Self::new()
+                }
+            }
+        };
+    }
+
+    pub(crate) use cfg_log;
+    pub(crate) use impl_default;
+}
+
 /// Generate config instance from configuration.
 ///
 /// The most power of this crate is automatically deriving this trait.
